@@ -10,7 +10,7 @@ NULL
 #' @param aesthetics A [`character`] string or vector of character
 #'  strings listing the name(s) of the aesthetic(s) that this scale works with.
 #' @return A [discrete][ggplot2::discrete_scale] scale.
-#' @example inst/examples/ex-other-discrete.R
+# @example inst/examples/ex-other-discrete.R
 #' @family qualitative color schemes
 #' @author N. Frerebeau
 #' @name scale_logical_discrete
@@ -20,8 +20,11 @@ NULL
 #' @export
 #' @rdname scale_logical_discrete
 scale_colour_logical <- function(..., aesthetics = "colour") {
-  ggplot2::scale_color_manual(..., values = c("TRUE" = "black", "FALSE" = "white"),
-                              aesthetics = aesthetics)
+  ggplot2::scale_color_manual(
+    ...,
+    values = c(`TRUE` = "black", `FALSE` = "white"),
+    aesthetics = aesthetics
+  )
 }
 
 #' @export
@@ -31,6 +34,9 @@ scale_color_logical <- scale_colour_logical
 #' @export
 #' @rdname scale_logical_discrete
 scale_fill_logical <- function(..., aesthetics = "fill") {
-  ggplot2::scale_fill_manual(..., values = c("TRUE" = "black", "FALSE" = "white"),
-                             aesthetics = aesthetics)
+  ggplot2::scale_fill_manual(
+    ...,
+    values = c(`TRUE` = "black", `FALSE` = "white"),
+    aesthetics = aesthetics
+  )
 }
